@@ -13,6 +13,7 @@
 #include "config.h"
 #include "mpg123.h"
 #include "optimize.h"
+#include "getcpuflags.h"
 #include "id3.h"
 #include "icy.h"
 #include "reader.h"
@@ -139,8 +140,11 @@ struct mpg123_handle_struct
 	/* layer3 */
 	int longLimit[9][23];
 	int shortLimit[9][14];
+#ifdef REAL_IS_FIXED
+	const real *gainpow2; // Actually static storage elsewhere.
+#else
 	real gainpow2[256+118+4]; /* not really dynamic, just different for mmx */
-
+#endif
 	/* layer2 */
 	real muls[27][64];	/* also used by layer 1 */
 
@@ -164,7 +168,7 @@ struct mpg123_handle_struct
 
 #ifndef NO_LAYER3
 #if (defined OPT_3DNOW_VINTAGE || defined OPT_3DNOWEXT_VINTAGE || defined OPT_SSE || defined OPT_X86_64 || defined OPT_AVX || defined OPT_NEON || defined OPT_NEON64)
-		void (*the_dct36)(real *,real *,real *,real *,real *);
+		void (*the_dct36)(real *,real *,real *,const real *,real *);
 #endif
 #endif
 
@@ -172,7 +176,9 @@ struct mpg123_handle_struct
 		enum optdec type;
 		enum optcla class;
 	} cpu_opts;
-
+#ifdef OPT_CPU_FLAGS
+	struct cpuflags cpu_flags;
+#endif
 	int verbose;    /* 0: nothing, 1: just print chosen decoder, 2: be verbose */
 
 	const struct al_table *alloc;
